Index: src/core/SkBitmapCache.h |
diff --git a/src/core/SkBitmapCache.h b/src/core/SkBitmapCache.h |
index 3e541eed2c57f7c2d54bd5142fa72d7ae9c27e26..12be6fad359006e49a0c60aaee9732977c233438 100644 |
--- a/src/core/SkBitmapCache.h |
+++ b/src/core/SkBitmapCache.h |
@@ -27,17 +27,17 @@ public: |
static SkBitmap::Allocator* GetAllocator(); |
/** |
* Search based on the src bitmap and inverse scales in X and Y. If found, returns true and |
* result will be set to the matching bitmap with its pixels already locked. |
*/ |
- static bool Find(const SkBitmap& src, SkScalar invScaleX, SkScalar invScaleY, SkBitmap* result, |
- SkResourceCache* localCache = nullptr); |
+ static bool FindWH(const SkBitmap& src, int width, int height, SkBitmap* result, |
+ SkResourceCache* localCache = nullptr); |
/* |
* result must be marked isImmutable() |
*/ |
- static void Add(const SkBitmap& src, SkScalar invScaleX, SkScalar invScaleY, |
- const SkBitmap& result, SkResourceCache* localCache = nullptr); |
+ static void AddWH(const SkBitmap& src, int width, int height, const SkBitmap& result, |
+ SkResourceCache* localCache = nullptr); |
/** |
* Search based on the bitmap's genID and subset. If found, returns true and |
@@ -27,17 +27,17 @@ public: |
static SkBitmap::Allocator* GetAllocator(); |
/** |
- * Search based on the src bitmap and inverse scales in X and Y. If found, returns true and |
+ * Search based on the src bitmap and scaled width/height. If found, returns true and |
* result will be set to the matching bitmap with its pixels already locked. |
*/ |